@@ -1,4 +1,3 @@
-pub mod midi_events;
 pub mod midi_hub;
 pub mod midi_message;
 pub mod midi_plugin;
@@ -6,6 +5,8 @@ pub mod midi_settings;
 pub mod midi_state;
 pub mod midi_util;
 
+pub use notation_audio;
+
 #[cfg(not(target_arch = "wasm32"))]
 pub mod native;
 
@@ -14,8 +15,7 @@ pub mod wasm;
 
 pub mod prelude {
     #[doc(hidden)]
-    #[doc(hidden)]
-    pub use crate::midi_events::{JumpToBarEvent, PlayControlEvent, SwitchTabEvent};
+    pub use notation_audio::prelude::*;
     #[doc(hidden)]
     pub use crate::midi_hub::MidiHub;
     #[doc(hidden)]
