@@ -367,7 +367,7 @@ impl MidiState {
             }
         }
         for bar in tab.bars.iter() {
-            for lane in bar.lanes.iter() {
+            for ((_k, _i), lane) in bar.lanes.iter() {
                 if let Some(channel) = self.get_channel_mut(&lane.track.id, &lane.track.kind) {
                     for entry in lane.entries.iter() {
                         if let Some(msgs) = MidiUtil::get_midi_msgs(channel, bar, &entry) {
@@ -470,7 +470,7 @@ impl MidiState {
                     } else if x.prev_is_tie() {
                         None
                     } else {
-                        Some(x.props)
+                        Some(x.props.clone())
                     }
                 }) {
                     self.setup_seek(
@@ -507,7 +507,7 @@ impl MidiState {
                         } else if x.prev_is_tie() {
                             None
                         } else {
-                            Some(x.props)
+                            Some(x.props.clone())
                         }
                     }) {
                         self.setup_seek(pos.with_in_bar_pos(props.in_bar_pos));
